==> apache-tapestry-5.6.4-sources.zip: tapestry-core/src/main/java/org/apache/tapestry5/internal/bindings/NullFieldStrategyBindingFactory.java <==
// Copyright 2008, 2009 The Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.apache.tapestry5.internal.bindings;

import org.apache.tapestry5.Binding;
import org.apache.tapestry5.ComponentResources;
import org.apache.tapestry5.NullFieldStrategy;
import org.apache.tapestry5.ioc.Location;
import org.apache.tapestry5.services.BindingFactory;
import org.apache.tapestry5.services.NullFieldStrategySource;

/**
 * Treats the expression as the name of a {@link org.apache.tapestry5.NullFieldStrategy}, accessed via the {@link
 * org.apache.tapestry5.services.NullFieldStrategySource} service.
 */
public class NullFieldStrategyBindingFactory implements BindingFactory
{
    private NullFieldStrategySource strategySource;

    public NullFieldStrategyBindingFactory(NullFieldStrategySource strategySource)
    {
        this.strategySource = strategySource;
    }

    public Binding newBinding(String description, ComponentResources container, ComponentResources component,
                              String expression, Location location)
    {
        NullFieldStrategy strategy = strategySource.get(expression);

        return new LiteralBinding(location, description, strategy);
    }
}

==> apache-tapestry-5.7.2-sources.zip: tapestry-core/src/main/java/org/apache/tapestry5/internal/bindings/NullFieldStrategyBindingFactory.java <==
// Copyright 2008, 2009 The Apache Software Foundation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.apache.tapestry5.internal.bindings;

import org.apache.tapestry5.Binding;
import org.apache.tapestry5.ComponentResources;
import org.apache.tapestry5.NullFieldStrategy;
import org.apache.tapestry5.commons.Location;
import org.apache.tapestry5.services.BindingFactory;
import org.apache.tapestry5.services.NullFieldStrategySource;

/**
 * Treats the expression as the name of a {@link org.apache.tapestry5.NullFieldStrategy}, accessed via the {@link
 * org.apache.tapestry5.services.NullFieldStrategySource} service.
 */
public class NullFieldStrategyBindingFactory implements BindingFactory
{
    private NullFieldStrategySource strategySource;

    public NullFieldStrategyBindingFactory(NullFieldStrategySource strategySource)
    {
        this.strategySource = strategySource;
    }

    public Binding newBinding(String description, ComponentResources container, ComponentResources component,
                              String expression, Location location)
    {
        NullFieldStrategy strategy = strategySource.get(expression);

        return new LiteralBinding(location, description, strategy);
    }
}
